;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'tools '("hideshow"))
(custom-add-loads 'outlines '("hideshow"))
(custom-add-loads 'hide-ifdef '("hideif"))
(custom-add-loads 'c-macro '("cmacexp"))
(custom-add-loads 'hideshow '("hideshow"))
(custom-add-loads 'c '("cmacexp" "hideif"))

;;; custom-load.el ends here
